@@ -17,7 +17,7 @@ import errno
 import json
 import logging
 import os
-from datetime import datetime
+from datetime import datetime, timezone
 from typing import Dict, List
 
 from load_shedding.providers import eskom
@@ -48,15 +48,17 @@ def get_schedule(provider: Provider, province: Province, suburb: Suburb, stage:
     cached_schedules = {}
     cached_schedule = []
     try:
+        tz = timezone.utc
         cache_file = ".cache/{suburb_id}.json".format(suburb_id=suburb.id)
         with open(cache_file, "r") as cache:
-            cached_schedules = json.loads(cache.read(), object_pairs_hook=lambda pairs: {Stage(int(k)).value: v for k, v in pairs})
+            cached_schedules = json.loads(cache.read(), object_pairs_hook=lambda pairs: {
+                Stage(int(k)).value: v for k, v in pairs
+            })
             cached_schedule = cached_schedules.get(stage.value, [])
 
         if cached and cached_schedule:
-            today = datetime.now().date()
-            first = datetime.strptime(cached_schedule[0][0], "%Y-%m-%d %H:%M").date()
-            if first >= today:
+            first = datetime.fromisoformat(cached_schedule[0][0])
+            if first >= datetime.now(tz):
                 return cached_schedule
     except FileNotFoundError as e:
         logging.log(logging.ERROR, "Unable to get schedule from cache. {e}".format(e=e))
@@ -78,17 +80,21 @@ def get_schedule(provider: Provider, province: Province, suburb: Suburb, stage:
 
 def list_to_dict(schedule: list) -> Dict:
     schedule_dict = {}
-    now = datetime.now()
+    now = datetime.now(timezone.utc)
     for item in schedule:
-        start = datetime.strptime(item[0], "%Y-%m-%d %H:%M")
-        end = datetime.strptime(item[1], "%Y-%m-%d %H:%M")
+        start = datetime.fromisoformat(item[0])
+        end = datetime.fromisoformat(item[1])
 
-        schedule_dict[start.strftime("%Y-%m-%d")] = (
-            now.replace(month=start.month, day=start.day, hour=start.hour, minute=start.minute, microsecond=0).strftime(
-                "%H:%M"),
-            now.replace(month=end.month, day=end.day, hour=end.hour, minute=end.minute, microsecond=0).strftime(
-                "%H:%M"),
-        )
+        # schedule_dict[start.strftime("%Y-%m-%d")] = (
+        #     now.replace(month=start.month, day=start.day, hour=start.hour, minute=start.minute, microsecond=0).strftime(
+        #         "%H:%M"),
+        #     now.replace(month=end.month, day=end.day, hour=end.hour, minute=end.minute, microsecond=0).strftime(
+        #         "%H:%M"),
+        # )
+    schedule_dict[start.strftime("%Y-%m-%d")] = (
+        start.replace(second=now.second).strftime("%H:%M"),
+        end.replace(second=now.second).strftime("%H:%M"),
+    )
     return schedule_dict
 
 
