@@ -14,7 +14,7 @@
 #      You should have received a copy of the GNU General Public License
 #      along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
-import datetime
+from datetime import datetime, timedelta, timezone
 import json
 import logging
 from typing import List, Tuple, Any
@@ -49,6 +49,12 @@ class Suburb(Suburb):
         self.province = Eskom.province_from_name(kwargs.get("ProvinceName"))
         self.total = kwargs.get("Total")
 
+    def __str__(self):
+        return str(self.name)
+
+    def __repr__(self):
+        return self.name, self.municipality, self.province
+
 
 class Municipality(Municipality):
     def __init__(self, /, **kwargs):
@@ -58,6 +64,12 @@ class Municipality(Municipality):
         self.group = kwargs.get("Group")
         self.disabled = kwargs.get("Disabled")
 
+    def __str__(self):
+        return str(self.name)
+
+    def __repr__(self):
+        return self.name
+
 
 # TODO: Improve error handling when Eskom responds with an error.
 class Eskom(Provider):
@@ -80,9 +92,9 @@ class Eskom(Provider):
             "2": Stage.STAGE_1,
             "3": Stage.STAGE_2,
             "4": Stage.STAGE_3,
-            "6": Stage.STAGE_4,
-            "5": Stage.STAGE_6,
-            "7": Stage.STAGE_5,
+            "5": Stage.STAGE_4,
+            "6": Stage.STAGE_5,
+            "7": Stage.STAGE_6,
             "8": Stage.STAGE_7,
             "9": Stage.STAGE_8,
         }.get(status, Stage.UNKNOWN)
@@ -118,25 +130,27 @@ class Eskom(Provider):
 
         if not days_soup:
             logging.log(logging.ERROR, "Unable to parse schedule. {data}".format(data=data))
-            raise ProviderError("Eskom is unavailable.") from None
+            raise ProviderError(f"No data available (Suburb ID: {suburb.id})") from None
 
-        now = datetime.datetime.now()
+        sast = timezone(timedelta(hours=+2), 'SAST')
+        utc = timezone.utc
+        now = datetime.now(sast)
         for day in days_soup:
             date_soup = day.find("div", attrs={"class": "dayMonth"})
             date_str = date_soup.get_text().strip()
-            date = datetime.datetime.strptime(date_str, "%a, %d %b")
+            date = datetime.strptime(date_str, "%a, %d %b")
             date = date.replace(year=now.year)
 
             time_soup = day.find_all("a")
             for time_tag in time_soup:
                 start_str, end_str = time_tag.get_text().strip().split(" - ")
-                start = datetime.datetime.strptime(start_str, "%H:%M")
-                end = datetime.datetime.strptime(end_str, "%H:%M")
+                start = datetime.strptime(start_str, "%H:%M")
+                end = datetime.strptime(end_str, "%H:%M")
                 schedule.append((
                     now.replace(month=date.month, day=date.day, hour=start.hour, minute=start.minute, second=0,
-                                microsecond=0).strftime("%Y-%m-%d %H:%M"),
+                                microsecond=0, tzinfo=sast).astimezone(utc).isoformat(),
                     now.replace(month=date.month, day=date.day, hour=end.hour, minute=end.minute, second=0,
-                                microsecond=0).strftime("%Y-%m-%d %H:%M")
+                                microsecond=0, tzinfo=sast).astimezone(utc).isoformat()
                 ))
 
         return schedule
@@ -189,3 +203,6 @@ def _get_response(url: str) -> Any:
     except urllib3.exceptions.HTTPError as e:
         logging.log(logging.ERROR, "Eskom is unavailable. {e}".format(e=e))
         raise ProviderError("Eskom is unavailable.") from None
+
+
+# https://loadshedding.eskom.co.za/LoadShedding/GetSurburbData/?callback=jQuery191009689061272138111_1650382595946&pageSize=100&pageNum=1&searchTerm=&id=342&_=1650382595947
\ No newline at end of file
